@@ -46,20 +46,14 @@
 
 MainWindow::MainWindow(MainWindow *pParent) :
     QMainWindow(),
-    m_webPage(this)
-{
-    m_pBookmarks = NULL;
-
+    m_webPage(this), m_pParent(pParent),
 #ifdef Q_WS_MAEMO_5
-    m_pOrientationSelector = NULL;
-    m_pUserAgentSelector = NULL;
+    m_pOrientationSelector(NULL), m_pUserAgentSelector(NULL),
 #endif
-
-    m_pParent = pParent;
-
+    m_pBookmarks(NULL)
+{
     setWindowTitle("Macuco");
 
-
 #ifdef Q_WS_MAEMO_5
     FullScreenExitButton *pButt = new FullScreenExitButton(this);
     connect(pButt, SIGNAL(clicked()), this, SLOT(showNormal()));
@@ -148,9 +142,6 @@ MainWindow::~MainWindow() {
 
     qDebug() << ">> top most window";
     if ( m_pBookmarks ) {delete m_pBookmarks; m_pBookmarks = NULL;}
-
-    // delete children windows
-    while ( !m_children.isEmpty() ) delete m_children.takeLast();
 }
 
 void MainWindow::createMenu() {
@@ -373,26 +364,9 @@ void MainWindow::closeEvent(QCloseEvent *event)
 #endif
 
     if ( !m_pParent ) {
-        if (!m_children.isEmpty()) {
-            if ( QMessageBox::question(this, "Close Application",
-                "Closing this window will close all other macuco windows.\n"
-                "Would you like to continue?",
-                QMessageBox::Yes, QMessageBox::No
-                )!=QMessageBox::Yes
-            ) {
-                event->ignore();
-                return;
-            }
-        }
-
         // top most
         saveSettings();
         m_webPage.saveCookies();
-
-    } else {
-        qDebug() << "remove from parent list and schedule for deletion";
-        m_pParent->m_children.removeOne(this);
-        deleteLater();
     }
 
     event->accept();
